@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: SQLite setup/teardown for tests
 
-our $VERSION = '0.0401';
+our $VERSION = '0.0402';
 
 use Moo;
 use strictures 2;
@@ -130,7 +130,7 @@ Test::SQLite - SQLite setup/teardown for tests
 
 =head1 VERSION
 
-version 0.0401
+version 0.0402
 
 =head1 SYNOPSIS
 
@@ -169,7 +169,8 @@ version 0.0401
 =head1 DESCRIPTION
 
 C<Test::SQLite> is inspired by L<Test::PostgreSQL> and
-L<Test::mysqld>, and creates a temporary db to use in tests.
+L<Test::mysqld>, and creates a temporary sqlite database to use in
+tests.
 
 This module will also return the database B<dbh> handle, B<dsn>
 connection string, and B<db_attrs> connection attributes.
@@ -244,6 +245,8 @@ L<File::Temp>
 
 L<Moo>
 
+L<namespace::clean>
+
 =head1 THANK YOU
 
 Kaitlyn Parkhurst (SYMKAT) <symkat@symkat.com>
